import { IconButton } from '@suid/material';
import { Component, createSignal, Show } from 'solid-js';
import { Geolocation } from '@awesome-cordova-plugins/geolocation';

import NoteIcon from '@suid/icons-material/Note';

import style from './Note.module.css';
import WptEditDialog, { Category } from '../wpt/WptEditDialog';
import { Coordinate } from 'ol/coordinate';

interface Props {}

const Note: Component<Props> = (props) => {
  const [open, setOpen] = createSignal<boolean>(false);
  const [coordinate, setCoordinate] = createSignal<Coordinate>();

  const openWptEditDialogWithCurrentLocation = async () => {
    const position = await Geolocation.getCurrentPosition();
    setCoordinate([position.coords.longitude, position.coords.latitude]);
    setOpen(true);
  };

  const initialWpt = () => {
    const time = new Date().toISOString();
    return {
      $: { lat: 0, lon: 0 },
      ele: undefined,
      time: undefined,
      magvar: undefined,
      geoidheight: undefined,
      name: undefined,
      cmt: undefined,
      desc: undefined,
      src: undefined,
      link: undefined,
      sym: undefined,
      type: undefined,
      fix: undefined,
      sat: undefined,
      hdop: undefined,
      vdop: undefined,
      pdop: undefined,
      ageofdgpsdata: undefined,
      dgpsid: undefined,
      extensions: {
        address: undefined,
        startTime: time,
        endTime: time,
        category: Category.NOTE,
        subCategory: undefined,
      },
    };
  };

  return (
    <>
      <div
        class={
          window.Capacitor.platform === 'web'
            ? style.control_web
            : style.control
        }
      >
        {' '}
        <IconButton onClick={openWptEditDialogWithCurrentLocation}>
          <NoteIcon />
        </IconButton>
      </div>
      <Show when={open()}>
        <WptEditDialog
          open={open}
          closeHandler={() => setOpen(false)}
          coordinate={coordinate}
          initialWpt={initialWpt}
        />
      </Show>
    </>
  );
};

export default Note;
