import { Component } from 'solid-js';
import { peekCachedSignal } from '../../workers/cached-signals';
import Tree from '../tree';
import TrkIcon from '../../icons/human-footprints-svgrepo-com.svg?component-solid';
import { useI18n } from '@solid-primitives/i18n';
import { getFormattedLength } from '../../lib/ol';
import { DisplayOrGetStartEndAddresses } from '../display-or-get-address';
import { LineString } from 'ol/geom';
import { getFormattedHeightStats } from '../../lib/height';

interface Props {
  trksegId: string;
}

const TrksegViewer: Component<Props> = ({ trksegId }) => {
  const [t, { add, locale, dict }] = useI18n();

  const trkseg = peekCachedSignal({ id: trksegId, action: 'getTrkseg' });
  console.log({ caller: 'TrksegViewer', trksegId, trkseg: trkseg() });

  const lineString = new LineString(
    trkseg().trkpt.map((trkpt: any) => [trkpt.$.lon, trkpt.$.lat])
  );

  const firstTrkpt = () => trkseg().trkpt.at(0);
  const lastTrkpt = () => trkseg().trkpt.at(-1);

  const title = () => {
    return firstTrkpt().time;
  };

  return (
    <Tree
      title={
        <>
          <span>
            <TrkIcon fill='white' width='16' height='16' /> {title()}
          </span>
        </>
      }
      content={
        <>
          <div>
            {getFormattedLength(lineString)}{' '}
            <DisplayOrGetStartEndAddresses
              id={trksegId}
              wpts={() => trkseg().trkpt}
              putAction='putTrkpt'
            />{', '}
            {getFormattedHeightStats(trkseg().trkpt)}
          </div>
        </>
      }
      subTree={undefined}
    />
  );
};

export default TrksegViewer;
