import { Component, createEffect, onCleanup } from 'solid-js';

import VectorSource from 'ol/source/Vector';
import GeoJSON from 'ol/format/GeoJSON';
import { useI18n } from '@solid-primitives/i18n';
import { cloneDeep } from 'lodash';
import {
  createCachedSignal,
  destroyCachedSignal,
} from '../../workers/cached-signals';
import { fromLonLat } from 'ol/proj';

interface Props {
  wptId: string;
  vectorSources: VectorSource[];
  context: any;
}

export const Wpt: Component<Props> = ({
  vectorSources,
  wptId: wptId,
  context,
}) => {
  const [t, { add, locale, dict }] = useI18n();

  const params = {
    id: wptId,
    method: 'getWpt',
  };
  const wpt = createCachedSignal(params);

  onCleanup(() => {
    console.log({
      caller: 'Wpt / onCleanup',
      wptId,
      wpt: wpt(),
      params,
    });

    destroyCachedSignal(params);
  });

  const getTitle = () => {
    if (wpt()?.name) {
      return `${wpt()?.name} (${t('wpt')})`;
    }
    return t('wpt');
  };

  createEffect(() => {
    console.log({ caller: 'Wpt', vectorSources, wptId, wpt: cloneDeep(wpt()) });

    if (wpt()) {
      const existingFeature = vectorSources[0].getFeatureById(wptId);
      if (existingFeature) {
        vectorSources[0].removeFeature(existingFeature);
      }
      let geo: any = {
        type: 'FeatureCollection',
        features: [
          {
            type: 'Feature',
            geometry: {
              type: 'Point',
              coordinates: fromLonLat([wpt()?.$.lon, wpt()?.$.lat]),
            },
            properties: {
              type: 'wpt',
              ...wpt(),
              id: wptId,
              getTitle,
              context: { ...context, wpt, wptId },
            },
            id: wptId,
          },
        ],
      };

      const features = new GeoJSON().readFeatures(geo);
      console.log({ caller: 'Wpt', features });
      const feature0 = vectorSources[0].getFeatureById(wptId);
      if (feature0) {
        vectorSources[0].removeFeature(feature0);
      }
      const feature1 = vectorSources[1].getFeatureById(wptId);
      if (feature1) {
        vectorSources[1].removeFeature(feature1);
      }
      if (false && wpt()?.extensions?.category === 'note') {
        vectorSources[1].addFeatures(features);
      } else {
        vectorSources[0].addFeatures(features);
      }
    }
  });

  return <></>;
};

export default Wpt;
