import { afterEach, beforeEach, describe, expect, it, vi } from 'vitest';
import maybePlusCode from './check-pluscodes';

describe('The maybePlusCode method', () => {
  it('detects a valid short pluscode without qualifier', () => {
    const code = '9G8F+6W';
    expect(maybePlusCode(code)).toEqual({ code, isShort: true });
  });
  it('detects a valid short pluscode with qualifier', () => {
    const code = '948G+V4 Oviedo';
    expect(maybePlusCode(code)).toEqual({
      code: '948G+V4',
      qualifier: 'Oviedo',
      isShort: true,
    });
  });
  it('detects a valid long pluscode with 10 digits', () => {
    const code = '9FFW84J9+XG';
    expect(maybePlusCode(code)).toEqual({
      code,
      isShort: false,
    });
  });
  it('detects a valid long pluscode with 8 digits', () => {
    const code = '9FFW84J9+';
    expect(maybePlusCode(code)).toEqual({
      code,
      isShort: false,
    });
  });
  it('detects a valid long pluscode with 4 digits', () => {
    const code = '9FFW0000+';
    expect(maybePlusCode(code)).toEqual({
      code,
      isShort: false,
    });
  });
});
