export const getHeightStats = (wpts: Wpt[]) => {
  let previous: number | null = null,
    previousAvg: number | null = null,
    min: number | null = null,
    max: number | null = null,
    positive: number = 0,
    negative: number = 0;

  wpts.forEach((wpt) => {
    if (wpt.ele) {
      const ele = 10 * Math.round(wpt.ele / 10);
      if (!max || ele > max) {
        max = ele;
      }
      if (!min || ele < min) {
        min = ele;
      }
      if (previous) {
        const avg = (ele + previous) / 2;
        if (previousAvg) {
          if (avg > previousAvg) {
            positive += avg - previousAvg;
          } else {
            negative += avg - previousAvg;
          }
        }
        previousAvg = avg;
      }
      previous = ele;
    }
  });
  return { min, max, positive, negative };
};

export const getFormattedHeightStats = (wpts: Wpt[]) => {
  const { min, max, positive, negative } = getHeightStats(wpts);
  return `d+ : ${positive}m, d- : ${negative}m`;
};
