import { cloneDeep } from 'lodash';

const downsizeCanvas = (canvas: HTMLCanvasElement, maxSize: number) => {
  const currentMaxSize = Math.max(canvas.width, canvas.height);
  const ratio = currentMaxSize / maxSize;
  const targetWidth = canvas.width / ratio;
  const targetHeight = canvas.height / ratio;
  const nbStepsReal = Math.log2(ratio);
  const nbSteps = Math.floor(nbStepsReal);
  let width = canvas.width;
  let height = canvas.height;
  const canvasCtx = canvas.getContext('2d');

  for (let i = 0; i < nbSteps; i++) {
    width = width / 2;
    height = height / 2;
    canvasCtx?.drawImage(canvas, 0, 0, canvas.width / 2, canvas.height / 2);
  }

  const finalCanvas = document.createElement('canvas');
  finalCanvas.height = targetHeight;
  finalCanvas.width = targetWidth;
  const finalCanvasCtx = finalCanvas.getContext('2d');
  finalCanvasCtx?.drawImage(
    canvas,
    0,
    0,
    width,
    height,
    0,
    0,
    targetWidth,
    targetHeight
  );

  return finalCanvas;
};

export const downsize = (imageUrl: string, maxSizes: number[]) => {
  let resolver = (resizedImageUrl: any) => {};
  const img = document.createElement('img');
  img.onload = () => {
    let canvas = document.createElement('canvas');
    canvas.width = img.width;
    canvas.height = img.height;
    const canvasCtx = canvas.getContext('2d');
    canvasCtx?.drawImage(img, 0, 0);

    img.remove();

    const canvases = maxSizes.map((maxSize: number) => {
      canvas = downsizeCanvas(canvas, maxSize);
      return canvas.toDataURL('image/jpeg');
    });

    resolver(canvases);
  };

  img.src = imageUrl;
  return new Promise((resolve, reject) => {
    resolver = resolve;
  });
};
