import {
  TagDefinitions,
  TagFormatDefinition,
  TagType,
} from './activities-and-categories';

interface TagStatus {
  type?: TagType;
  definition?: TagFormatDefinition;
  highlighted: boolean;
}

export const getTagStatus = (
  tag: string,
  definitions: TagDefinitions,
  selectedKey: string,
  highlightedKey: string
): TagStatus => {
  const defaultStatus = {
    highlighted: false,
  };
  const activityDefinitions = definitions[selectedKey];
  if (!activityDefinitions) {
    return defaultStatus;
  }

  for (const type of Object.values(TagType)) {
    const typeDefinitions = activityDefinitions[type as TagType];

    if (!!typeDefinitions) {
      const highlightedDefinitions = typeDefinitions[highlightedKey];

      if (!!highlightedDefinitions) {
        const definition = highlightedDefinitions[tag];
        if (!!definition) {
          return { type, definition, highlighted: true };
        }
      }

      for (const category of Object.keys(typeDefinitions)) {
        if (category !== highlightedKey) {
          const categoryDefinitions = typeDefinitions[category];
          const definition = categoryDefinitions[tag];
          if (!!definition) {
            return { type, definition, highlighted: false };
          }
        }
      }
    }
  }

  return defaultStatus;
};
